==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Основна інформація</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Деталі</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Додати до альбому</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>усі зображення</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Видалити з альбому</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з улубленого</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Улюблене</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Ви не маєте дозволу на перегляд зображення</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата зміни</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата захоплення</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експозиції</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програма експозиції</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Час експозиції</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Спалах</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Діафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусна відстань</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс. діафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим виміру експозиції</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс білого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсація спалаху</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель об&apos;єктиву</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Кольорова палітра</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камери</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Розмірність</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Тег</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Розмір 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Підібрати розмір за вікном</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Видобути текст</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Показати вікно навігації</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Сховати навігаційне вікно</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>day</source>
        <translation>день</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Підтвердження</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Вкажіть нову назву</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Відтворення</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Не знайдено файлів зображень</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Файл зображення не знайдено</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>У вас немає прав доступу до перегляду цього файла</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.25.orig.tar.xz: image-editor-1.0.25/libimageviewer/translations/libimageviewer_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Основна інформація</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Деталі</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Додати до альбому</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новий альбом</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>усі зображення</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Відкрити зображення</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Видалити з альбому</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Вилучити з улубленого</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Улюблене</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Ви не маєте дозволу на перегляд зображення</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата зміни</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Розмір файлу</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата захоплення</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим експозиції</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програма експозиції</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Час експозиції</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Спалах</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Діафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусна відстань</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Макс. діафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим виміру експозиції</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс білого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсація спалаху</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель об&apos;єктиву</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Кольорова палітра</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камери</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Розмірність</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Тег</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Розмір 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Підібрати розмір за вікном</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Видобути текст</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернути проти годинникової стрілки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернути за годинниковою стрілкою</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Вилучити</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Вийти з повноекранного режиму</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Повноекранний</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Друк</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Показ слайдів</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Перейменувати</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Показати вікно навігації</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Сховати навігаційне вікно</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Встановити як шпалери</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показати в файловому менеджері</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Інформація про зображення</translation>
    </message>
    <message>
        <source>day</source>
        <translation>день</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Підтвердження</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Вкажіть нову назву</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Попередній</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Відтворення</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Наступний</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Не знайдено файлів зображень</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Файл зображення не знайдено</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>У вас немає прав доступу до перегляду цього файла</translation>
    </message>
</context>
</TS>
